@@ -34,7 +34,7 @@ Options
 
   -h, --help            display this help message
 
-Without any options, the script does that the documentation says.
+Without any options, the script does what the documentation says.
 
 Output is the same for uncompiled and compiled script.
 """
@@ -131,15 +131,14 @@ def main(argv):
     '''compiler and help/example/documentation extractor'''
     global RtAdHoc
     RtAdHoc.macros = macros
-    
+
     if len(argv) > 1:
         if argv[1].startswith('-h') or argv[1].startswith('--h'):
             print(__doc__)
             return 1
         if (argv[1].startswith('--c')
             or argv[1].startswith('--d')
-            or argv[1].startswith('--t')
-            or argv[1].startswith('--r')):
+            or argv[1].startswith('--t')):
             file_, source = RtAdHoc.std_source_param(__file__)
             if 'adhoc' not in globals() and 'rt_adhoc' not in globals():
                 compiled = source
@@ -153,17 +152,6 @@ def main(argv):
             if argv[1].startswith('--t'):
                 template(RtAdHoc.activate_macros(source))
                 return 1
-                # switch to meta tags
-                sv = RtAdHoc.set_delimiters (('<:', ':>'))
-                docu_input = RtAdHoc.activate_macros(source)
-                docu_input = docu_input.replace('t:' 'adhoc', '<:' 'adhoc')
-                docu_input = docu_input.replace('u:' 'adhoc', '@:' 'adhoc')
-                docu_input = RtAdHoc.get_named_template(source=docu_input)
-                docu_input = RtAdHoc.line_tag_remove(docu_input, '[^:]+', True, ('o:', ':>'))
-                docu_input = RtAdHoc.line_tag_remove(docu_input, '[^:]+', True, ('i:', ':>'))
-                RtAdHoc.write_source('-', docu_input)
-                RtAdHoc.reset_delimiters(sv)
-                return 1
             if compiled is None:
                 compiled = RtAdHoc().compile(source)
             if argv[1].startswith('--c'):
@@ -172,23 +160,6 @@ def main(argv):
             if argv[1].startswith('--d'):
                 documentation()
                 return 1
-                # switch to meta tags
-                sv = RtAdHoc.set_delimiters (('<:', ':>'))
-                docu_input = RtAdHoc.activate_macros(source)
-                docu_input = docu_input.replace('i:' 'adhoc', '<:' 'adhoc')
-                docu_input = docu_input.replace('u:' 'adhoc', '@:' 'adhoc')
-                docu_input = RtAdHoc.get_named_template(source=docu_input)
-                docu_input = RtAdHoc.line_tag_remove(docu_input, '[^:]+', True, ('o:', ':>'))
-                RtAdHoc.write_source('-', docu_input)
-
-                docu_input = RtAdHoc.activate_macros(compiled)
-                docu_input = docu_input.replace('i:' 'adhoc', '<:' 'adhoc')
-                docu_input = docu_input.replace('o:' 'adhoc', '<:' 'adhoc')
-                docu_input = docu_input.replace('u:' 'adhoc', '@:' 'adhoc')
-                docu_input = RtAdHoc.get_named_template(source=docu_input)
-                RtAdHoc.write_source('-', docu_input)
-                RtAdHoc.reset_delimiters(sv)
-                return 1
         map(sys.stderr.write, ('error: unknown option `', str(argv[1]), '`\n'))
         exit(1)
     return 0
@@ -213,6 +184,7 @@ try:
     from adhoc import AdHoc as RtAdHoc
 except ImportError:
     try:
+        import rt_adhoc
         from rt_adhoc import RtAdHoc
     except ImportError:
         pass
@@ -267,16 +239,6 @@ def template(source=None):                                 # ||:fnc:||
     if source is None:
         source = RtAdHoc.read_source(__file__)
 
-    # state = RtAdHoc.set_delimiters('<:', ':>')
-    # parts = []
-    # parts.append(''.join((RtAdHoc.section_tag('adhoc_indent'), ' -4\n')))
-    # parts.append(''.join((RtAdHoc.section_tag('adhoc_template'), ' -\n')))
-    # parts.append(source)
-    # parts.append(''.join((RtAdHoc.section_tag('adhoc_template'), ' -\n')))
-    # parts.append(''.join((RtAdHoc.section_tag('adhoc_indent'), '\n')))
-    # source = RtAdHoc.get_named_template('-', None, ''.join(parts))
-    # RtAdHoc.reset_delimiters(state)
-
     source = source.replace('<:' 'adhoc', '@:' 'adhoc')
     source = source.replace('@:' 'adhoc_indent' ':@ -0', '@:' 'adhoc_indent' ':@ -4')
 
@@ -303,11 +265,6 @@ def documentation():                                       # ||:fnc:||
     example_raw = RtAdHoc.get_named_template('-example', __file__)
     RtAdHoc.reset_delimiters(state)
 
-    # printe(sformat(
-    #     "{0}{3:^{1}} {4:<{2}s}: ]{5!s}[",
-    #     dbg_comm, dbg_twid, dbg_fwid, ':DBG:', 'example_raw', example_raw))
-    # exit(0)                             # |:debug:|
-
     full_doc_delimiters = ('@:', ':>')
     state = RtAdHoc.set_delimiters(full_doc_delimiters)
     example1 = RtAdHoc.section_tag_remove(example_raw, 'adhoc_template')
